@@ -117,6 +117,19 @@ class Indentables:
         logger.debug(requesteds)
         self.requesteds = list(requesteds)
 
+    def alphabetize_terms(self, term_list) -> list:
+        lf = self.label_frame
+        lf = lf.loc[lf['class'].isin(term_list)]
+        lf = lf.sort_values(by='label')
+        alphabetized = list(lf['class'])
+        # logger.info(lf)
+        return alphabetized
+
+    def alphabetize_requesteds(self):
+        term_list = self.requesteds
+        alphabetized = self.alphabetize_terms(term_list)
+        self.requesteds = alphabetized
+
     def prepare_frame(self, frame_file_name: str, cols_to_tidy: list[str], header=1, sep="\t") -> pd.DataFrame:
         # assuming they're full IRIs (but without < or >
         logger.debug(frame_file_name)
@@ -164,9 +177,10 @@ class Indentables:
         else:
             term_dict = self.dump_term(term_id)
             term_lab = term_dict['term_lab']
-            indented_lab = padding + term_lab
+            indented_lab = padding + term_lab + " [" + term_id + "]"
             self.append_id_lab(term_id, indented_lab)
             subs = term_dict['subs']
+            subs = self.alphabetize_terms(subs)
             for i in subs:
                 new_indent_level = indent_level + 1
                 self.indent_from_term(i, new_indent_level)
@@ -204,6 +218,7 @@ def hident(curie_file_name, sco_tab_file_name, lab_tab_file_name, indented_tsv):
     current_indentables.requesteds_from_txt_file(curie_file_name)
     current_indentables.sco_from_txt_file(sco_tab_file_name)
     current_indentables.labs_from_txt_file(lab_tab_file_name)
+    current_indentables.alphabetize_requesteds()
     current_indentables.wrapper()
     id_lab_frame = current_indentables.get_ids_labs()
     # # left_aligned_ilf = id_lab_frame.style.set_properties(**{'text-align': 'left'})
